@@ -2,6 +2,7 @@ import asyncio
 import rlp
 import logging
 from time import sleep
+from datetime import datetime, timedelta, timezone
 
 import requests
 from requests.exceptions import RetryError
@@ -19,7 +20,7 @@ from axie_utils.graphql import AxieGraphQL, TrezorAxieGraphQL
 
 
 class Claim(AxieGraphQL):
-    def __init__(self, acc_name, **kwargs):
+    def __init__(self, acc_name, force, **kwargs):
         super().__init__(**kwargs)
         self.w3 = Web3(
             Web3.HTTPProvider(
@@ -30,8 +31,16 @@ class Claim(AxieGraphQL):
             abi=SLP_ABI
         )
         self.acc_name = acc_name
+        self.force = force
         self.request = requests.Session()
 
+    def localize_date(self, date_utc):
+        return date_utc.replace(tzinfo=timezone.utc).astimezone(tz=None)
+
+    def humanize_date(self, date):
+        local_date = self.localize_date(date)
+        return local_date.strftime("%m/%d/%Y, %H:%M")
+        
     def has_unclaimed_slp(self):
         url = f"https://game-api.skymavis.com/game-api/clients/{self.account}/items/1"
         try:
@@ -41,8 +50,17 @@ class Claim(AxieGraphQL):
                              f"({self.account.replace('0x','ronin:')})")
             return None
         if 200 <= response.status_code <= 299:
-            in_game_total = int(response.json()['total'])
+            data = response.json()
+            last_claimed = datetime.utcfromtimestamp(data['last_claimed_item_at'])
+            next_claim_date = last_claimed + timedelta(days=14)
+            utcnow = datetime.utcnow()
+            if utcnow < next_claim_date and not self.force:
+                logging.critical(f"This account will be claimable again on {self.humanize_date(next_claim_date)}.")
+                return None
+            elif self.force:
+                logging.info('Skipping check of dates, --force option was selected')
             wallet_total = check_balance(self.account)
+            in_game_total = int(data['total'])
             if in_game_total > wallet_total:
                 return in_game_total - wallet_total
         return None
@@ -193,7 +211,7 @@ class Claim(AxieGraphQL):
 
 
 class TrezorClaim(TrezorAxieGraphQL):
-    def __init__(self, acc_name, **kwargs):
+    def __init__(self, acc_name, force, **kwargs):
         super().__init__(**kwargs)
         self.w3 = Web3(
             Web3.HTTPProvider(
@@ -204,10 +222,19 @@ class TrezorClaim(TrezorAxieGraphQL):
             abi=SLP_ABI
         )
         self.acc_name = acc_name
+        self.force = force
         self.request = requests.Session()
         self.gwei = self.w3.toWei('1', 'gwei')
         self.gas = 492874
 
+    def localize_date(self, date_utc):
+        return date_utc.replace(tzinfo=timezone.utc).astimezone(tz=None)
+
+    def humanize_date(self, date):
+        local_date = self.localize_date(date)
+        return local_date.strftime("%m/%d/%Y, %H:%M")
+        
+        
     def has_unclaimed_slp(self):
         url = f"https://game-api.skymavis.com/game-api/clients/{self.account}/items/1"
         try:
@@ -217,8 +244,17 @@ class TrezorClaim(TrezorAxieGraphQL):
                              f"({self.account.replace('0x','ronin:')})")
             return None
         if 200 <= response.status_code <= 299:
-            in_game_total = int(response.json()['total'])
+            data = response.json()
+            last_claimed = datetime.utcfromtimestamp(data['last_claimed_item_at'])
+            next_claim_date = last_claimed + timedelta(days=14)
+            utcnow = datetime.utcnow()
+            if utcnow < next_claim_date and not self.force:
+                logging.critical(f"This account will be claimable again on {self.humanize_date(next_claim_date)}.")
+                return None
+            elif self.force:
+                logging.info('Skipping check of dates, --force option was selected')
             wallet_total = check_balance(self.account)
+            in_game_total = int(data['total'])
             if in_game_total > wallet_total:
                 return in_game_total - wallet_total
         return None
